==> foundry_platform_sdk-0.84.0.tar.gz: foundry_platform_sdk-0.84.0/foundry/v2/datasets/errors/_file_not_found_on_transaction_range.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from dataclasses import dataclass
from typing import Literal

import pydantic
from typing_extensions import NotRequired
from typing_extensions import TypedDict

from foundry._errors import PalantirRPCException
from foundry.v2.core.models._file_path import FilePath
from foundry.v2.datasets.models._dataset_rid import DatasetRid
from foundry.v2.datasets.models._transaction_rid import TransactionRid


class FileNotFoundOnTransactionRangeParameters(TypedDict):
    """The requested file could not be found on the given transaction range, or the client token does not have access to it."""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    datasetRid: DatasetRid

    startTransactionRid: NotRequired[TransactionRid]

    endTransactionRid: TransactionRid

    path: FilePath


@dataclass
class FileNotFoundOnTransactionRange(PalantirRPCException):
    name: Literal["FileNotFoundOnTransactionRange"]
    parameters: FileNotFoundOnTransactionRangeParameters
    error_instance_id: str


__all__ = ["FileNotFoundOnTransactionRange"]

==> foundry_platform_sdk-0.94.0.tar.gz: foundry_platform_sdk-0.94.0/foundry/v2/datasets/errors/_file_not_found_on_transaction_range.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from dataclasses import dataclass
from typing import Literal

from typing_extensions import NotRequired
from typing_extensions import TypedDict

from foundry._errors import NotFoundError
from foundry.v2.core.models._file_path import FilePath
from foundry.v2.datasets.models._dataset_rid import DatasetRid
from foundry.v2.datasets.models._transaction_rid import TransactionRid


class FileNotFoundOnTransactionRangeParameters(TypedDict):
    """The requested file could not be found on the given transaction range, or the client token does not have access to it."""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    datasetRid: DatasetRid

    startTransactionRid: NotRequired[TransactionRid]

    endTransactionRid: TransactionRid

    path: FilePath


@dataclass
class FileNotFoundOnTransactionRange(NotFoundError):
    name: Literal["FileNotFoundOnTransactionRange"]
    parameters: FileNotFoundOnTransactionRangeParameters
    error_instance_id: str


__all__ = ["FileNotFoundOnTransactionRange"]
